@@ -4,7 +4,6 @@ This module is a scratchpad for general development, testing & debugging.
 
 from django.core.management.base import NoArgsCommand
 from django.db import connection
-
 from pexp.models import *
 
 
@@ -19,9 +18,7 @@ class Command(NoArgsCommand):
         Project.objects.all().delete()
         a = Project.objects.create(topic="John's gathering")
         b = ArtProject.objects.create(topic="Sculpting with Tim", artist="T. Turner")
-        c = ResearchProject.objects.create(
-            topic="Swallow Aerodynamics", supervisor="Dr. Winter"
-        )
+        c = ResearchProject.objects.create(topic="Swallow Aerodynamics", supervisor="Dr. Winter")
         print(Project.objects.all())
         print("")
 
