@@ -3,10 +3,11 @@ Rendering utils for admin forms;
 
 This makes sure that admin fieldsets/layout settings are exported to the template.
 """
+
 import json
 
 from django.contrib.admin.helpers import AdminField, InlineAdminForm, InlineAdminFormSet
-from django.utils.encoding import force_text
+from django.utils.encoding import force_str
 from django.utils.text import capfirst
 from django.utils.translation import gettext
 
@@ -35,15 +36,13 @@ class PolymorphicInlineAdminFormSet(InlineAdminFormSet):
         # Assigned later via PolymorphicInlineSupportMixin later.
         self.request = kwargs.pop("request", None)
         self.obj = kwargs.pop("obj", None)
-        super(PolymorphicInlineAdminFormSet, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def __iter__(self):
         """
         Output all forms using the proper subtype settings.
         """
-        for form, original in zip(
-            self.formset.initial_forms, self.formset.get_queryset()
-        ):
+        for form, original in zip(self.formset.initial_forms, self.formset.get_queryset()):
             # Output the form
             model = original.get_real_instance_class()
             child_inline = self.opts.get_child_inline_instance(model)
@@ -93,7 +92,7 @@ class PolymorphicInlineAdminFormSet(InlineAdminFormSet):
         verbose_name = self.opts.verbose_name
         return json.dumps(
             {
-                "name": "#%s" % self.formset.prefix,
+                "name": f"#{self.formset.prefix}",
                 "options": {
                     "prefix": self.formset.prefix,
                     "addText": gettext("Add another %(verbose_name)s")
@@ -101,7 +100,7 @@ class PolymorphicInlineAdminFormSet(InlineAdminFormSet):
                     "childTypes": [
                         {
                             "type": model._meta.model_name,
-                            "name": force_text(model._meta.verbose_name),
+                            "name": force_str(model._meta.verbose_name),
                         }
                         for model in self.formset.child_forms.keys()
                     ],
@@ -111,7 +110,7 @@ class PolymorphicInlineAdminFormSet(InlineAdminFormSet):
         )
 
 
-class PolymorphicInlineSupportMixin(object):
+class PolymorphicInlineSupportMixin:
     """
     A Mixin to add to the regular admin, so it can work with our polymorphic inlines.
 
@@ -124,17 +123,15 @@ class PolymorphicInlineSupportMixin(object):
     :class:`~django.contrib.admin.helpers.InlineAdminFormSet` for the polymorphic formsets.
     """
 
-    def get_inline_formsets(
-        self, request, formsets, inline_instances, obj=None, *args, **kwargs
-    ):
+    def get_inline_formsets(self, request, formsets, inline_instances, obj=None, *args, **kwargs):
         """
         Overwritten version to produce the proper admin wrapping for the
         polymorphic inline formset. This fixes the media and form appearance
         of the inline polymorphic models.
         """
-        inline_admin_formsets = super(
-            PolymorphicInlineSupportMixin, self
-        ).get_inline_formsets(request, formsets, inline_instances, obj=obj)
+        inline_admin_formsets = super().get_inline_formsets(
+            request, formsets, inline_instances, obj=obj
+        )
 
         for admin_formset in inline_admin_formsets:
             if isinstance(admin_formset.formset, BasePolymorphicModelFormSet):
