@@ -1,13 +1,13 @@
-# -*- coding: utf-8 -*-
 """
 QuerySet for PolymorphicModel
 """
+
 import copy
 from collections import defaultdict
 
-from django import get_version as get_django_version
 from django.contrib.contenttypes.models import ContentType
 from django.core.exceptions import FieldDoesNotExist
+from django.db.models import FilteredRelation
 from django.db.models.query import ModelIterable, Q, QuerySet
 
 from .query_translate import (
@@ -31,7 +31,7 @@ class PolymorphicModelIterable(ModelIterable):
     """
 
     def __iter__(self):
-        base_iter = super(PolymorphicModelIterable, self).__iter__()
+        base_iter = super().__iter__()
         if self.queryset.polymorphic_disabled:
             return base_iter
         return self._polymorphic_iterator(base_iter)
@@ -53,7 +53,6 @@ class PolymorphicModelIterable(ModelIterable):
             # Make sure the base iterator is read in chunks instead of
             # reading it completely, in case our caller read only a few objects.
             for i in range(Polymorphic_QuerySet_objects_per_request):
-
                 try:
                     o = next(base_iter)
                     base_result_objects.append(o)
@@ -101,7 +100,7 @@ class PolymorphicQuerySet(QuerySet):
     """
 
     def __init__(self, *args, **kwargs):
-        super(PolymorphicQuerySet, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self._iterable_class = PolymorphicModelIterable
 
         self.polymorphic_disabled = False
@@ -110,11 +109,11 @@ class PolymorphicQuerySet(QuerySet):
         # .defer() and .only() in order to be able to retranslate them when
         # retrieving the real instance (so that the deferred fields apply
         # to that queryset as well).
-        self.polymorphic_deferred_loading = (set([]), True)
+        self.polymorphic_deferred_loading = (set(), True)
 
     def _clone(self, *args, **kwargs):
         # Django's _clone only copies its own variables, so we need to copy ours here
-        new = super(PolymorphicQuerySet, self)._clone(*args, **kwargs)
+        new = super()._clone(*args, **kwargs)
         new.polymorphic_disabled = self.polymorphic_disabled
         new.polymorphic_deferred_loading = (
             copy.copy(self.polymorphic_deferred_loading[0]),
@@ -132,11 +131,11 @@ class PolymorphicQuerySet(QuerySet):
     as_manager.queryset_only = True
     as_manager = classmethod(as_manager)
 
-    def bulk_create(self, objs, batch_size=None):
+    def bulk_create(self, objs, batch_size=None, ignore_conflicts=False):
         objs = list(objs)
         for obj in objs:
             obj.pre_save_polymorphic()
-        return super(PolymorphicQuerySet, self).bulk_create(objs, batch_size)
+        return super().bulk_create(objs, batch_size, ignore_conflicts=ignore_conflicts)
 
     def non_polymorphic(self):
         """switch off polymorphic behaviour for this query.
@@ -158,34 +157,17 @@ class PolymorphicQuerySet(QuerySet):
         # Implementation in _translate_polymorphic_filter_defnition."""
         return self.filter(not_instance_of=args)
 
-    # Makes _filter_or_exclude compatible with the change in signature introduced in django at 9c9a3fe
-    if get_django_version() >= "3.2":
-        def _filter_or_exclude(self, negate, args, kwargs):
-            # We override this internal Django function as it is used for all filter member functions.
-            q_objects = translate_polymorphic_filter_definitions_in_args(
-                queryset_model=self.model, args=args, using=self.db
-            )
-            # filter_field='data'
-            additional_args = translate_polymorphic_filter_definitions_in_kwargs(
-                queryset_model=self.model, kwargs=kwargs, using=self.db
-            )
-            args = list(q_objects) + additional_args
-            return super(PolymorphicQuerySet, self)._filter_or_exclude(
-                negate=negate, args=args, kwargs=kwargs
-            )
-    else:
-        def _filter_or_exclude(self, negate, *args, **kwargs):
-            # We override this internal Django function as it is used for all filter member functions.
-            q_objects = translate_polymorphic_filter_definitions_in_args(
-                self.model, args, using=self.db
-            )
-            # filter_field='data'
-            additional_args = translate_polymorphic_filter_definitions_in_kwargs(
-                self.model, kwargs, using=self.db
-            )
-            return super(PolymorphicQuerySet, self)._filter_or_exclude(
-                negate, *(list(q_objects) + additional_args), **kwargs
-            )
+    def _filter_or_exclude(self, negate, args, kwargs):
+        # We override this internal Django function as it is used for all filter member functions.
+        q_objects = translate_polymorphic_filter_definitions_in_args(
+            queryset_model=self.model, args=args, using=self.db
+        )
+        # filter_field='data'
+        additional_args = translate_polymorphic_filter_definitions_in_kwargs(
+            queryset_model=self.model, kwargs=kwargs, using=self.db
+        )
+        args = list(q_objects) + additional_args
+        return super()._filter_or_exclude(negate=negate, args=args, kwargs=kwargs)
 
     def order_by(self, *field_names):
         """translate the field paths in the args, then call vanilla order_by."""
@@ -195,7 +177,7 @@ class PolymorphicQuerySet(QuerySet):
             else a  # allow expressions to pass unchanged
             for a in field_names
         ]
-        return super(PolymorphicQuerySet, self).order_by(*field_names)
+        return super().order_by(*field_names)
 
     def defer(self, *fields):
         """
@@ -206,7 +188,7 @@ class PolymorphicQuerySet(QuerySet):
         them again, as the model will have changed).
         """
         new_fields = [translate_polymorphic_field_path(self.model, a) for a in fields]
-        clone = super(PolymorphicQuerySet, self).defer(*new_fields)
+        clone = super().defer(*new_fields)
         clone._polymorphic_add_deferred_loading(fields)
         return clone
 
@@ -219,7 +201,7 @@ class PolymorphicQuerySet(QuerySet):
         them again, as the model will have changed).
         """
         new_fields = [translate_polymorphic_field_path(self.model, a) for a in fields]
-        clone = super(PolymorphicQuerySet, self).only(*new_fields)
+        clone = super().only(*new_fields)
         clone._polymorphic_add_immediate_loading(fields)
         return clone
 
@@ -257,7 +239,8 @@ class PolymorphicQuerySet(QuerySet):
 
     def _process_aggregate_args(self, args, kwargs):
         """for aggregate and annotate kwargs: allow ModelX___field syntax for kwargs, forbid it for args.
-        Modifies kwargs if needed (these are Aggregate objects, we translate the lookup member variable)"""
+        Modifies kwargs if needed (these are Aggregate objects, we translate the lookup member variable)
+        """
         ___lookup_assert_msg = "PolymorphicModel: annotate()/aggregate(): ___ model lookup supported for keyword arguments only"
 
         def patch_lookup(a):
@@ -265,6 +248,8 @@ class PolymorphicQuerySet(QuerySet):
             # stored inside a complex query expression.
             if isinstance(a, Q):
                 translate_polymorphic_Q_object(self.model, a)
+            elif isinstance(a, FilteredRelation):
+                patch_lookup(a.condition)
             elif hasattr(a, "get_source_expressions"):
                 for source_expression in a.get_source_expressions():
                     if source_expression is not None:
@@ -273,12 +258,12 @@ class PolymorphicQuerySet(QuerySet):
                 a.name = translate_polymorphic_field_path(self.model, a.name)
 
         def test___lookup(a):
-            """ *args might be complex expressions too in django 1.8 so
-            the testing for a '___' is rather complex on this one """
+            """*args might be complex expressions too in django 1.8 so
+            the testing for a '___' is rather complex on this one"""
             if isinstance(a, Q):
 
                 def tree_node_test___lookup(my_model, node):
-                    " process all children of this Q node "
+                    "process all children of this Q node"
                     for i in range(len(node.children)):
                         child = node.children[i]
 
@@ -305,7 +290,7 @@ class PolymorphicQuerySet(QuerySet):
         """translate the polymorphic field paths in the kwargs, then call vanilla annotate.
         _get_real_instances will do the rest of the job after executing the query."""
         self._process_aggregate_args(args, kwargs)
-        return super(PolymorphicQuerySet, self).annotate(*args, **kwargs)
+        return super().annotate(*args, **kwargs)
 
     def aggregate(self, *args, **kwargs):
         """translate the polymorphic field paths in the kwargs, then call vanilla aggregate.
@@ -318,7 +303,7 @@ class PolymorphicQuerySet(QuerySet):
     # same class as 'qs', so our polymorphic modifications would apply.
     # We want to leave values queries untouched, so we set 'polymorphic_disabled'.
     def _values(self, *args, **kwargs):
-        clone = super(PolymorphicQuerySet, self)._values(*args, **kwargs)
+        clone = super()._values(*args, **kwargs)
         clone.polymorphic_disabled = True
         return clone
 
@@ -383,15 +368,12 @@ class PolymorphicQuerySet(QuerySet):
         ).pk
 
         for i, base_object in enumerate(base_result_objects):
-
             if base_object.polymorphic_ctype_id == self_model_class_id:
                 # Real class is exactly the same as base class, go straight to results
                 resultlist.append(base_object)
             else:
                 real_concrete_class = base_object.get_real_instance_class()
-                real_concrete_class_id = (
-                    base_object.get_real_concrete_instance_class_id()
-                )
+                real_concrete_class_id = base_object.get_real_concrete_instance_class_id()
 
                 if real_concrete_class_id is None:
                     # Dealing with a stale content type
@@ -405,12 +387,8 @@ class PolymorphicQuerySet(QuerySet):
                     real_concrete_class = content_type_manager.get_for_id(
                         real_concrete_class_id
                     ).model_class()
-                    idlist_per_model[real_concrete_class].append(
-                        getattr(base_object, pk_name)
-                    )
-                    indexlist_per_model[real_concrete_class].append(
-                        (i, len(resultlist))
-                    )
+                    idlist_per_model[real_concrete_class].append(getattr(base_object, pk_name))
+                    indexlist_per_model[real_concrete_class].append((i, len(resultlist)))
                     resultlist.append(None)
 
         # For each model in "idlist_per_model" request its objects (the real model)
@@ -421,7 +399,7 @@ class PolymorphicQuerySet(QuerySet):
         for real_concrete_class, idlist in idlist_per_model.items():
             indices = indexlist_per_model[real_concrete_class]
             real_objects = real_concrete_class._base_objects.db_manager(self.db).filter(
-                **{("%s__in" % pk_name): idlist}
+                **{(f"{pk_name}__in"): idlist}
             )
             # copy select related configuration to new qs
             real_objects.query.select_related = self.query.select_related
@@ -458,8 +436,7 @@ class PolymorphicQuerySet(QuerySet):
             )
 
             real_objects_dict = {
-                getattr(real_object, pk_name): real_object
-                for real_object in real_objects
+                getattr(real_object, pk_name): real_object for real_object in real_objects
             }
 
             for i, j in indices:
@@ -509,15 +486,15 @@ class PolymorphicQuerySet(QuerySet):
 
     def __repr__(self, *args, **kwargs):
         if self.model.polymorphic_query_multiline_output:
-            result = [repr(o) for o in self.all()]
-            return "[ " + ",\n  ".join(result) + " ]"
+            result = ",\n  ".join(repr(o) for o in self.all())
+            return f"[ {result} ]"
         else:
-            return super(PolymorphicQuerySet, self).__repr__(*args, **kwargs)
+            return super().__repr__(*args, **kwargs)
 
     class _p_list_class(list):
         def __repr__(self, *args, **kwargs):
-            result = [repr(o) for o in self]
-            return "[ " + ",\n  ".join(result) + " ]"
+            result = ",\n  ".join(repr(o) for o in self)
+            return f"[ {result} ]"
 
     def get_real_instances(self, base_result_objects=None):
         """
@@ -538,4 +515,4 @@ class PolymorphicQuerySet(QuerySet):
         if not self.model.polymorphic_query_multiline_output:
             return olist
         clist = PolymorphicQuerySet._p_list_class(olist)
-        return clist
\ No newline at end of file
+        return clist
