@@ -1,6 +1,7 @@
 """
 PolymorphicQuerySet support functions
 """
+
 import copy
 from collections import deque
 
@@ -16,7 +17,6 @@ from django.db.utils import DEFAULT_DB_ALIAS
 # They form a kind of small framework for easily adding more
 # functionality to filters and Q objects.
 # Probably a more general queryset enhancement class could be made out of them.
-from polymorphic import compat
 
 ###################################################################################
 # PolymorphicQuerySet support functions
@@ -39,8 +39,7 @@ def translate_polymorphic_filter_definitions_in_kwargs(
     Returns: a list of non-keyword-arguments (Q objects) to be added to the filter() query.
     """
     additional_args = []
-    for field_path, val in kwargs.copy().items():  # Python 3 needs copy
-
+    for field_path, val in kwargs.copy().items():  # `copy` so we're not mutating the dict
         new_expr = _translate_polymorphic_filter_definition(
             queryset_model, field_path, val, using=using
         )
@@ -142,7 +141,7 @@ def translate_polymorphic_field_path(queryset_model, field_path):
     classname, sep, pure_field_path = field_path.partition("___")
     if not sep:
         return field_path
-    assert classname, "PolymorphicModel: %s: bad field specification" % field_path
+    assert classname, f"PolymorphicModel: {field_path}: bad field specification"
 
     negated = False
     if classname[0] == "-":
@@ -153,10 +152,7 @@ def translate_polymorphic_field_path(queryset_model, field_path):
         # the user has app label prepended to class name via __ => use Django's get_model function
         appname, sep, classname = classname.partition("__")
         model = apps.get_model(appname, classname)
-        assert model, "PolymorphicModel: model {} (in app {}) not found!".format(
-            model.__name__,
-            appname,
-        )
+        assert model, f"PolymorphicModel: model {model.__name__} (in app {appname}) not found!"
         if not issubclass(model, queryset_model):
             e = (
                 'PolymorphicModel: queryset filter error: "'
@@ -186,10 +182,7 @@ def translate_polymorphic_field_path(queryset_model, field_path):
 
         submodels = _get_all_sub_models(queryset_model)
         model = submodels.get(classname, None)
-        assert model, "PolymorphicModel: model {} not found (not a subclass of {})!".format(
-            classname,
-            queryset_model.__name__,
-        )
+        assert model, f"PolymorphicModel: model {classname} not found (not a subclass of {queryset_model.__name__})!"
 
     basepath = _create_base_path(queryset_model, model)
 
@@ -216,15 +209,13 @@ def _get_all_sub_models(base_model):
         if issubclass(model, models.Model) and model != models.Model:
             # model name is occurring twice in submodel inheritance tree => Error
             if model.__name__ in result and model != result[model.__name__]:
+                name1 = f"{model._meta.app_label}.{model.__name__}"
+                name2 = (
+                    f"{result[model.__name__]._meta.app_label}.{result[model.__name__].__name__}"
+                )
                 raise FieldError(
-                    "PolymorphicModel: model name alone is ambiguous: %s.%s and %s.%s match!\n"
-                    "In this case, please use the syntax: applabel__ModelName___field"
-                    % (
-                        model._meta.app_label,
-                        model.__name__,
-                        result[model.__name__]._meta.app_label,
-                        result[model.__name__].__name__,
-                    )
+                    f"PolymorphicModel: model name alone is ambiguous: {name1} and {name2} match!\n"
+                    f"In this case, please use the syntax: applabel__ModelName___field"
                 )
 
             result[model.__name__] = model
@@ -245,7 +236,7 @@ def _create_base_path(baseclass, myclass):
             if b._meta.abstract or b._meta.proxy:
                 return _get_query_related_name(myclass)
             else:
-                return path + "__" + _get_query_related_name(myclass)
+                return f"{path}__{_get_query_related_name(myclass)}"
     return ""
 
 
